==> com.liferay.dynamic.data.mapping.form.web-3.0.42.jar: META-INF/resources/admin/js/components/PreviewButton/PreviewButton.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-web@3.0.42/admin/js/components/PreviewButton/PreviewButton.es", ['module', 'exports', 'require', 'frontend-taglib-clay$clay-button', 'frontend-js-metal-web$metal-jsx', 'frontend-js-metal-web$metal-state', '../../util/Notifications.es'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = void 0;

    var _clayButton = _interopRequireDefault(require("frontend-taglib-clay$clay-button"));

    var _metalJsx = _interopRequireDefault(require("frontend-js-metal-web$metal-jsx"));

    var _metalState = require("frontend-js-metal-web$metal-state");

    var _Notifications = _interopRequireDefault(require("../../util/Notifications.es"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    function _classCallCheck(instance, Constructor) {
      if (!(instance instanceof Constructor)) {
        throw new TypeError("Cannot call a class as a function");
      }
    }

    function _defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    function _createClass(Constructor, protoProps, staticProps) {
      if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
    }

    function _possibleConstructorReturn(self, call) {
      if (call && (_typeof(call) === "object" || typeof call === "function")) {
        return call;
      }return _assertThisInitialized(self);
    }

    function _assertThisInitialized(self) {
      if (self === void 0) {
        throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
      }return self;
    }

    function _getPrototypeOf(o) {
      _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
        return o.__proto__ || Object.getPrototypeOf(o);
      };return _getPrototypeOf(o);
    }

    function _inherits(subClass, superClass) {
      if (typeof superClass !== "function" && superClass !== null) {
        throw new TypeError("Super expression must either be null or a function");
      }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
    }

    function _setPrototypeOf(o, p) {
      _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
        o.__proto__ = p;return o;
      };return _setPrototypeOf(o, p);
    }

    var PreviewButton = /*#__PURE__*/function (_Component) {
      _inherits(PreviewButton, _Component);

      function PreviewButton() {
        _classCallCheck(this, PreviewButton);

        return _possibleConstructorReturn(this, _getPrototypeOf(PreviewButton).apply(this, arguments));
      }

      _createClass(PreviewButton, [{
        key: "preview",
        value: function preview() {
          var resolvePreviewURL = this.props.resolvePreviewURL;
          return resolvePreviewURL().then(function (previewURL) {
            window.open(previewURL, '_blank');
            return previewURL;
          })["catch"](function () {
            _Notifications["default"].showError(Liferay.Language.get('your-request-failed-to-complete'));
          });
        }
      }, {
        key: "render",
        value: function render() {
          var spritemap = this.props.spritemap;
          return IncrementalDOM.elementVoid(_clayButton["default"], null, null, "events", {
            click: this._handleButtonClicked.bind(this)
          }, "label", Liferay.Language.get('preview-form'), "spritemap", spritemap, "ref", 'button', "style", 'link');
        }
      }, {
        key: "_handleButtonClicked",
        value: function _handleButtonClicked() {
          this.preview();
        }
      }]);

      return PreviewButton;
    }(_metalJsx["default"]);

    PreviewButton.PROPS = {
      resolvePreviewURL: _metalState.Config.func().required(),
      spritemap: _metalState.Config.string().required()
    };
    var _default = PreviewButton;
    exports["default"] = _default;
    //# sourceMappingURL=PreviewButton.es.js.map
  }
});
//# sourceMappingURL=PreviewButton.es.js.map

==> com.liferay.dynamic.data.mapping.form.web-3.0.77.jar: META-INF/resources/admin/js/components/PreviewButton/PreviewButton.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-web@3.0.77/admin/js/components/PreviewButton/PreviewButton.es", ['module', 'exports', 'require', 'frontend-taglib-clay$clay-button', 'frontend-js-metal-web$metal-jsx', 'frontend-js-metal-web$metal-state', '../../util/Notifications.es'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = void 0;

    var _clayButton = _interopRequireDefault(require("frontend-taglib-clay$clay-button"));

    var _metalJsx = _interopRequireDefault(require("frontend-js-metal-web$metal-jsx"));

    var _metalState = require("frontend-js-metal-web$metal-state");

    var _Notifications = _interopRequireDefault(require("../../util/Notifications.es"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    function _typeof(obj) {
      "@babel/helpers - typeof";
      if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
        _typeof = function _typeof(obj) {
          return typeof obj;
        };
      } else {
        _typeof = function _typeof(obj) {
          return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
        };
      }return _typeof(obj);
    }

    function _classCallCheck(instance, Constructor) {
      if (!(instance instanceof Constructor)) {
        throw new TypeError("Cannot call a class as a function");
      }
    }

    function _defineProperties(target, props) {
      for (var i = 0; i < props.length; i++) {
        var descriptor = props[i];descriptor.enumerable = descriptor.enumerable || false;descriptor.configurable = true;if ("value" in descriptor) descriptor.writable = true;Object.defineProperty(target, descriptor.key, descriptor);
      }
    }

    function _createClass(Constructor, protoProps, staticProps) {
      if (protoProps) _defineProperties(Constructor.prototype, protoProps);if (staticProps) _defineProperties(Constructor, staticProps);return Constructor;
    }

    function _possibleConstructorReturn(self, call) {
      if (call && (_typeof(call) === "object" || typeof call === "function")) {
        return call;
      }return _assertThisInitialized(self);
    }

    function _assertThisInitialized(self) {
      if (self === void 0) {
        throw new ReferenceError("this hasn't been initialised - super() hasn't been called");
      }return self;
    }

    function _getPrototypeOf(o) {
      _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) {
        return o.__proto__ || Object.getPrototypeOf(o);
      };return _getPrototypeOf(o);
    }

    function _inherits(subClass, superClass) {
      if (typeof superClass !== "function" && superClass !== null) {
        throw new TypeError("Super expression must either be null or a function");
      }subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } });if (superClass) _setPrototypeOf(subClass, superClass);
    }

    function _setPrototypeOf(o, p) {
      _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) {
        o.__proto__ = p;return o;
      };return _setPrototypeOf(o, p);
    }

    var PreviewButton = /*#__PURE__*/function (_Component) {
      _inherits(PreviewButton, _Component);

      function PreviewButton() {
        _classCallCheck(this, PreviewButton);

        return _possibleConstructorReturn(this, _getPrototypeOf(PreviewButton).apply(this, arguments));
      }

      _createClass(PreviewButton, [{
        key: "preview",
        value: function preview() {
          var resolvePreviewURL = this.props.resolvePreviewURL;
          return resolvePreviewURL().then(function (previewURL) {
            window.open(previewURL, '_blank');
            return previewURL;
          }).catch(function () {
            _Notifications.default.showError(Liferay.Language.get('your-request-failed-to-complete'));
          });
        }
      }, {
        key: "render",
        value: function render() {
          var spritemap = this.props.spritemap;
          return IncrementalDOM.elementVoid(_clayButton.default, null, null, "events", {
            click: this._handleButtonClicked.bind(this)
          }, "label", Liferay.Language.get('preview-form'), "spritemap", spritemap, "ref", 'button', "style", 'link');
        }
      }, {
        key: "_handleButtonClicked",
        value: function _handleButtonClicked() {
          this.preview();
        }
      }]);

      return PreviewButton;
    }(_metalJsx.default);

    PreviewButton.PROPS = {
      resolvePreviewURL: _metalState.Config.func().required(),
      spritemap: _metalState.Config.string().required()
    };
    var _default = PreviewButton;
    exports.default = _default;
    //# sourceMappingURL=PreviewButton.es.js.map
  }
});
//# sourceMappingURL=PreviewButton.es.js.map
